Typinox
=======

**Typinox** (TAI-pee-nox) is a Python library for enhancing run-time type-checking of
`jaxtyping`-annotated arrays and `equinox.Module`s.

Installation
------------

```bash
pip install typinox
```

Documentation
-------------

The documentation is not yet available.

